<?php

function accessible_content_get_enabled_tests() {
  static $tests;
  if ($tests) {
    return $tests;
  }
  $tests = db_select('accessibility_test', 'a')
              ->fields('a', array('quail_name', 'name'))
              ->execute()
              ->fetchAllKeyed();
  return $tests;
}

function accessible_content_tests_list() {
  $library_path = libraries_get_path('quail');
  drupal_add_js(array('quail_guideline_path' => $library_path . '/src/resources/guidelines/'), 'setting');
  drupal_add_js(drupal_get_path('module', 'accessible_content') . '/js/accessible_content.admin.js');
  $options = array();
  $form = array();
  $tests = _accessible_content_get_quail_tests(true);
  $guidelines = accessible_content_get_guidelines();
  $guideline_links = array();
  foreach ($guidelines as $name => $label) {
    $guideline_links[] = l($label, '#', array('external' => TRUE, 'attributes' => array('class' => array('guideline'), 'data-guideline' => $name), 'fragment' => ''));
  }

  $form['guidelines'] = array(
    '#type' => 'fieldset',
    '#title' => t('Import entire guideline'),
    '#collapsible' => TRUE,
  );
  
  $form['guidelines']['guideline_links'] = array(
    '#type' => 'markup',
    '#markup' => theme('item_list', array('items' => $guideline_links)),
  );
  $enabled_tests = accessible_content_get_enabled_tests();
  
  foreach ($tests as $testname => $test) {
    if (!isset($enabled_tests[$testname])) {
      $options[$testname] = t('@name - %severity', array('@name' => t($test->readableName), '%severity' => t($test->severity)));
    }
  }
  
  $form['all_tests'] = array(
    '#type' => 'fieldset',
    '#title' => t('View all tests'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  
  $form['all_tests']['tests'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Available accessibility tests'),
    '#options' => $options,
    '#default_value' => $enabled_tests,
  );
  
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Import tests'),
  );
    
  return $form;
}

function accessible_content_tests_list_submit($form, $form_state) {
  $tests = _accessible_content_get_quail_tests(true);
  $enabled_tests = accessible_content_get_enabled_tests();
  $batch = array(
    'operations' => array(),
    'finished' => 'accessible_cotnent_tests_list_done',
    'title' => t('Importing tests'),
    'init_message' => t('Starting to import tests.'),
    'progress_message' => t('Imported @current out of @total.'),
    'error_message' => t('An error occurred while importing tests.'),
    'file' => drupal_get_path('module', 'accessible_content') . '/accessible_content.admin.inc',
  );
  foreach ($form_state['values']['tests'] as $test => $enabled) {
    if ($enabled && !isset($enabled_tests[$test])) {
      $batch['operations'][] = array('_accessible_content_create_test_from_quail', array($test, $tests[$test]));
    }
  }

  batch_set($batch);
}

function accessible_cotnent_tests_list_done($success, $results, $operations) {
  if ($success) {
    // Here we do something meaningful with the results.
    $message = count($results) . ' imported.';
    $message .= theme('item_list', $results);
  }
  else {
    // An error occurred.
    // $operations contains the operations that remained unprocessed.
    $error_operation = reset($operations);
    $message = t('An error occurred while processing %error_operation with arguments: @arguments', array('%error_operation' => $error_operation[0], '@arguments' => print_r($error_operation[1], TRUE)));
  }
  drupal_set_message($message);
}

function _accessible_content_create_test_from_quail($quail_name, $test, &$context) {
  $language = language_default();
  $new_test = new stdClass();
  $new_test->language = $language->language;
  $new_test->quail_name = $quail_name;
  $new_test->name = $test->readableName;
  $new_test->severity = ($test->severity) ? $test->severity : 'suggestion';
  $new_test->error_description[$new_test->language][0]['value'] = 
    array('value' => $test->body,
          'format' => 'filtered_html');
  $test = accessible_content_test_save($new_test);
  $context['message'] = t('Done importing @name', array('@name' => $test->name));
  $context['results'][] = $test->name;
}

function accessible_content_settings() {
  $form = array();
  
  $form['accessible_content_auto_check'] = array(
    '#type' => 'checkbox',
    '#title' => t('Automatically check page'),
    '#default_value' => variable_get('accessible_content_auto_check', FALSE),
  );
  
  $form['accessible_content_show_toggle'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show accessibility check toggle'),
    '#default_value' => variable_get('accessible_content_show_toggle', FALSE),
  );
  
  if (module_exists('beautytips')) {
    $form['accessible_content_use_beautytips'] = array(
      '#type' => 'checkbox',
      '#title' => t('Use beautytips to show hints'),
      '#default_value' => variable_get('accessible_content_use_beautytips', TRUE),
    );
  }
  
  $form['toggle'] = array(
    '#type' => 'fieldset',
    '#title' => t('Toggle settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  
  $form['toggle']['accessible_content_toggle_message_off'] = array(
    '#type' => 'textfield',
    '#title' => t('Message to show when accessibility checking is off'),
    '#default_value' => variable_get('accessible_content_toggle_message_off', t('Check page for accessibility')),
  );
  
  $form['toggle']['accessible_content_toggle_message_on'] = array(
    '#type' => 'textfield',
    '#title' => t('Message to show when accessibility checking is on'),
    '#default_value' => variable_get('accessible_content_toggle_message_on', t('Hide checks for accessibility')),
  );
  
  return system_settings_form($form);
}